@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +7,10 @@
 #pragma once
 
 #include <MessageViewer/ViewerPluginInterface>
+#include <PimCommon/ShareServiceUrlManager>
 #include <WebEngineViewer/CheckPhishingUrlJob>
 #include <WebEngineViewer/WebEngineView>
 #include <openurlrequest.h>
-#include <shareserviceurlmanager.h>
 
 class KActionCollection;
 namespace WebEngineViewer
