@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,9 +14,7 @@ DownloadFeedIconJob::DownloadFeedIconJob(QObject *parent)
 {
 }
 
-DownloadFeedIconJob::~DownloadFeedIconJob()
-{
-}
+DownloadFeedIconJob::~DownloadFeedIconJob() = default;
 
 bool DownloadFeedIconJob::start()
 {
